@@ -2,9 +2,10 @@ use std::fmt::Debug;
 
 use pyo3::prelude::*;
 use pyo3::types::{PyBytes, PyDict};
+use pyo3::{PyTraverseError, PyVisit};
 
 use crate::build_context::BuildContext;
-use crate::SchemaValidator;
+use crate::validators::SelfValidator;
 
 use config::SerializationConfig;
 pub use errors::{PydanticSerializationError, PydanticSerializationUnexpectedValue};
@@ -34,8 +35,10 @@ pub struct SchemaSerializer {
 impl SchemaSerializer {
     #[new]
     pub fn py_new(py: Python, schema: &PyDict, config: Option<&PyDict>) -> PyResult<Self> {
-        let schema = SchemaValidator::validate_schema(py, schema)?;
-        let mut build_context = BuildContext::for_schema(schema)?;
+        let self_validator = SelfValidator::new(py)?;
+        let schema = self_validator.validate_schema(py, schema)?;
+        let mut build_context = BuildContext::new(schema)?;
+
         let serializer = CombinedSerializer::build(schema.downcast()?, config, &mut build_context)?;
         Ok(Self {
             serializer,
@@ -134,6 +137,21 @@ impl SchemaSerializer {
             self.serializer, self.slots
         )
     }
+
+    fn __traverse__(&self, visit: PyVisit<'_>) -> Result<(), PyTraverseError> {
+        self.serializer.py_gc_traverse(&visit)?;
+        for slot in self.slots.iter() {
+            slot.py_gc_traverse(&visit)?;
+        }
+        Ok(())
+    }
+
+    fn __clear__(&mut self) {
+        self.serializer.py_gc_clear();
+        for slot in self.slots.iter_mut() {
+            slot.py_gc_clear();
+        }
+    }
 }
 
 #[allow(clippy::too_many_arguments)]
