@@ -470,7 +470,7 @@ def test_model_field_before_validator() -> None:
             core_schema.typed_dict_schema(
                 {
                     'x': core_schema.typed_dict_field(
-                        core_schema.field_before_validation_function(f, core_schema.str_schema())
+                        core_schema.field_before_validator_function(f, core_schema.str_schema())
                     )
                 }
             ),
@@ -499,7 +499,7 @@ def test_model_field_after_validator() -> None:
             core_schema.typed_dict_schema(
                 {
                     'x': core_schema.typed_dict_field(
-                        core_schema.field_after_validation_function(f, core_schema.str_schema())
+                        core_schema.field_after_validator_function(f, core_schema.str_schema())
                     )
                 }
             ),
@@ -526,7 +526,7 @@ def test_model_field_plain_validator() -> None:
         core_schema.model_schema(
             Model,
             core_schema.typed_dict_schema(
-                {'x': core_schema.typed_dict_field(core_schema.field_plain_validation_function(f))}
+                {'x': core_schema.typed_dict_field(core_schema.field_plain_validator_function(f))}
             ),
         )
     )
@@ -541,7 +541,9 @@ def test_model_field_wrap_validator() -> None:
         def __init__(self, **kwargs: Any) -> None:
             self.__dict__.update(kwargs)
 
-    def f(input_value: Any, val: core_schema.CallableValidator, info: core_schema.FieldValidationInfo) -> Any:
+    def f(
+        input_value: Any, val: core_schema.ValidatorFunctionWrapHandler, info: core_schema.FieldValidationInfo
+    ) -> Any:
         assert info.field_name == 'x'
         assert info.data == {}
         assert isinstance(input_value, bytes)
@@ -553,7 +555,7 @@ def test_model_field_wrap_validator() -> None:
             core_schema.typed_dict_schema(
                 {
                     'x': core_schema.typed_dict_field(
-                        core_schema.field_wrap_validation_function(f, core_schema.str_schema())
+                        core_schema.field_wrap_validator_function(f, core_schema.str_schema())
                     )
                 }
             ),
@@ -590,7 +592,7 @@ def test_non_model_field_before_validator_tries_to_access_field_info() -> None:
             core_schema.typed_dict_schema(
                 {
                     'x': core_schema.typed_dict_field(
-                        core_schema.general_before_validation_function(f, core_schema.str_schema())
+                        core_schema.general_before_validator_function(f, core_schema.str_schema())
                     )
                 }
             ),
@@ -617,7 +619,7 @@ def test_non_model_field_after_validator_tries_to_access_field_info() -> None:
             core_schema.typed_dict_schema(
                 {
                     'x': core_schema.typed_dict_field(
-                        core_schema.general_after_validation_function(f, core_schema.str_schema())
+                        core_schema.general_after_validator_function(f, core_schema.str_schema())
                     )
                 }
             ),
@@ -643,7 +645,7 @@ def test_non_model_field_plain_validator_tries_to_access_field_info() -> None:
         core_schema.model_schema(
             Model,
             core_schema.typed_dict_schema(
-                {'x': core_schema.typed_dict_field(core_schema.general_plain_validation_function(f))}
+                {'x': core_schema.typed_dict_field(core_schema.general_plain_validator_function(f))}
             ),
         )
     )
@@ -658,7 +660,7 @@ def test_non_model_field_wrap_validator_tries_to_access_field_info() -> None:
         def __init__(self, **kwargs: Any) -> None:
             self.__dict__.update(kwargs)
 
-    def f(input_value: Any, val: core_schema.CallableValidator, info: core_schema.ValidationInfo) -> Any:
+    def f(input_value: Any, val: core_schema.ValidatorFunctionWrapHandler, info: core_schema.ValidationInfo) -> Any:
         check_that_info_has_no_model_data(info)
         return f'input: {val(input_value)}'
 
@@ -668,7 +670,7 @@ def test_non_model_field_wrap_validator_tries_to_access_field_info() -> None:
             core_schema.typed_dict_schema(
                 {
                     'x': core_schema.typed_dict_field(
-                        core_schema.general_wrap_validation_function(f, core_schema.str_schema())
+                        core_schema.general_wrap_validator_function(f, core_schema.str_schema())
                     )
                 }
             ),
@@ -706,7 +708,7 @@ def test_typed_dict_data() -> None:
                 'a': core_schema.typed_dict_field(core_schema.int_schema()),
                 'b': core_schema.typed_dict_field(core_schema.int_schema()),
                 'c': core_schema.typed_dict_field(
-                    core_schema.field_after_validation_function(f, core_schema.str_schema())
+                    core_schema.field_after_validator_function(f, core_schema.str_schema())
                 ),
             }
         )
