@@ -736,7 +736,7 @@ def test_validate_assignment_function():
                 {
                     'field_a': core_schema.typed_dict_field(core_schema.str_schema()),
                     'field_b': core_schema.typed_dict_field(
-                        core_schema.field_after_validation_function(func, core_schema.int_schema())
+                        core_schema.field_after_validator_function(func, core_schema.int_schema())
                     ),
                     'field_c': core_schema.typed_dict_field(core_schema.int_schema()),
                 },
